@@ -1,22 +1,9 @@
 /*
-    Copyright (c) 2007 Tobias Koenig <tokoe@kde.org>
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2014 Christian Mollekopf <mollekopf@kolabsys.com>
+    SPDX-FileCopyrightText: 2007 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2014 Christian Mollekopf <mollekopf@kolabsys.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "itemsync.h"
@@ -44,7 +31,7 @@ using namespace Akonadi;
 class Akonadi::ItemSyncPrivate : public JobPrivate
 {
 public:
-    ItemSyncPrivate(ItemSync *parent)
+    explicit ItemSyncPrivate(ItemSync *parent)
         : JobPrivate(parent)
         , mTransactionMode(ItemSync::SingleTransaction)
         , mCurrentTransaction(nullptr)
