@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2006 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectionmodifyjob.h"
@@ -32,7 +19,7 @@ using namespace Akonadi;
 class Akonadi::CollectionModifyJobPrivate : public JobPrivate
 {
 public:
-    CollectionModifyJobPrivate(CollectionModifyJob *parent)
+    explicit CollectionModifyJobPrivate(CollectionModifyJob *parent)
         : JobPrivate(parent)
     {
     }
@@ -100,7 +87,7 @@ void CollectionModifyJob::doStart()
     if (d->mCollection.d_ptr->mAttributeStorage.hasModifiedAttributes()) {
         cmd->setAttributes(ProtocolHelper::attributesToProtocol(d->mCollection.d_ptr->mAttributeStorage.modifiedAttributes()));
     }
-    if (auto attr = d->mCollection.attribute<Akonadi::PersistentSearchAttribute>()) {
+    if (auto *attr = d->mCollection.attribute<Akonadi::PersistentSearchAttribute>()) {
         cmd->setPersistentSearchCollections(attr->queryCollections());
         cmd->setPersistentSearchQuery(attr->queryString());
         cmd->setPersistentSearchRecursive(attr->isRecursive());
