@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2013 Daniel Vrátil <dvratil@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_ABSTRACTSEARCHPLUGIN
@@ -45,9 +32,7 @@ public:
     /**
      * Destructor.
      */
-    virtual ~AbstractSearchPlugin()
-    {
-    };
+    virtual ~AbstractSearchPlugin() = default;
 
     /**
      * Reimplement this method to provide the actual search capability.
@@ -60,6 +45,11 @@ public:
      */
     virtual QSet<qint64> search(const QString &query, const QVector<qint64> &collections, const QStringList &mimeTypes) = 0;
 
+protected:
+    explicit AbstractSearchPlugin() = default;
+
+private:
+    Q_DISABLE_COPY_MOVE(AbstractSearchPlugin)
 };
 
 }
