@@ -1,42 +1,29 @@
 /*
     Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "collectionview.h"
 
 #include "collection.h"
-#include "collectionmodel.h"
 #include "controlgui.h"
-
-#include <QAction>
-#include <QMimeData>
+#include "entitytreemodel.h"
 #include "akonadiwidgets_debug.h"
+
 #include <KLocalizedString>
-#include <QUrl>
 #include <KXMLGUIFactory>
 #include <kxmlguiwindow.h>
 
+#include <QAction>
+#include <QMimeData>
 #include <QTimer>
 #include <QUrlQuery>
 #include <QApplication>
 #include <QDragMoveEvent>
 #include <QHeaderView>
 #include <QMenu>
+#include <QUrl>
 
 using namespace Akonadi;
 
@@ -46,7 +33,7 @@ using namespace Akonadi;
 class Q_DECL_HIDDEN CollectionView::Private
 {
 public:
-    Private(CollectionView *parent)
+    explicit Private(CollectionView *parent)
         : mParent(parent)
     {
     }
@@ -55,7 +42,7 @@ public:
     void dragExpand();
     void itemClicked(const QModelIndex &index);
     void itemCurrentChanged(const QModelIndex &index);
-    bool hasParent(const QModelIndex &idx, Collection::Id parentId);
+    bool hasParent(const QModelIndex &idx, Collection::Id parentId) const;
 
     CollectionView *mParent = nullptr;
     QModelIndex dragOverIndex;
@@ -80,16 +67,16 @@ void CollectionView::Private::init()
     dragExpandTimer.setSingleShot(true);
     mParent->connect(&dragExpandTimer, &QTimer::timeout, mParent, [this]() { dragExpand(); });
 
-    mParent->connect(mParent, SIGNAL(clicked(QModelIndex)), mParent, SLOT(itemClicked(QModelIndex)));
+    mParent->connect(mParent, &QAbstractItemView::clicked, mParent, [this](const QModelIndex &mi) { itemClicked(mi); });
 
     ControlGui::widgetNeedsAkonadi(mParent);
 }
 
-bool CollectionView::Private::hasParent(const QModelIndex &idx, Collection::Id parentId)
+bool CollectionView::Private::hasParent(const QModelIndex &idx, Collection::Id parentId) const
 {
     QModelIndex idx2 = idx;
     while (idx2.isValid()) {
-        if (mParent->model()->data(idx2, CollectionModel::CollectionIdRole).toLongLong() == parentId) {
+        if (mParent->model()->data(idx2, EntityTreeModel::CollectionIdRole).toLongLong() == parentId) {
             return true;
         }
 
@@ -110,7 +97,7 @@ void CollectionView::Private::itemClicked(const QModelIndex &index)
         return;
     }
 
-    const Collection collection = index.model()->data(index, CollectionModel::CollectionRole).value<Collection>();
+    const Collection collection = index.model()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
     if (!collection.isValid()) {
         return;
     }
@@ -124,7 +111,7 @@ void CollectionView::Private::itemCurrentChanged(const QModelIndex &index)
         return;
     }
 
-    const Collection collection = index.model()->data(index, CollectionModel::CollectionRole).value<Collection>();
+    const Collection collection = index.model()->data(index, EntityTreeModel::CollectionRole).value<Collection>();
     if (!collection.isValid()) {
         return;
     }
@@ -157,8 +144,8 @@ void CollectionView::setModel(QAbstractItemModel *model)
     QTreeView::setModel(model);
     header()->setStretchLastSection(true);
 
-    connect(selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)),
-            this, SLOT(itemCurrentChanged(QModelIndex)));
+    connect(selectionModel(), &QItemSelectionModel::currentChanged,
+            this, [this](const QModelIndex &mi) { d->itemCurrentChanged(mi); });
 }
 
 void CollectionView::dragMoveEvent(QDragMoveEvent *event)
@@ -173,7 +160,7 @@ void CollectionView::dragMoveEvent(QDragMoveEvent *event)
     }
 
     // Check if the collection under the cursor accepts this data type
-    const QStringList supportedContentTypes = model()->data(index, CollectionModel::CollectionRole).value<Collection>().contentMimeTypes();
+    const QStringList supportedContentTypes = model()->data(index, EntityTreeModel::CollectionRole).value<Collection>().contentMimeTypes();
     const QMimeData *mimeData = event->mimeData();
     if (!mimeData) {
         return;
